/*
    myrrdin, a 2d tile engine
    Copyright (c) 2008 Friedrich Weber

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the Software), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
    THE SOFTWARE.
 */

module myrrdin.tileconsumer;

import dsfml.window.all;
import dsfml.system.all;
import dsfml.graphics.all;
import tango.io.Stdout;

import myrrdin.consumer;
import myrrdin.renderer;
import myrrdin.tileset;
import myrrdin.tilemap;

class TileConsumer : Consumer {
    public Tilemap map;

    this(Renderer renderer, Tilemap map) {
	super(renderer);
	this.map = map;
    }

    void draw() {
	 foreach(Sprite sprite; this.map.get_sprites()) {
	    this.renderer.draw(sprite);
	 }
    }

    bool handle_event(Event evt) {
	if (evt.Type == Event.EventType.MOUSEBUTTONPRESSED) {
	    Input input = this.renderer.app.getInput();
	    Vector2i tile = this.map.real_to_tile(0, input.getMouseX(), input.getMouseY());
	    if(this.map.has_tile(0, tile.x, tile.y)) {
		Stdout.formatln("You clicked on the tile {}, {}", tile.x, tile.y);
	    }
	    return true;
	}	    
	return false;
    }
}
